pub struct ElectionMysqlClient {
current: Option<PoolConnection<MySql>>,
pool: MySqlPool,
execution_timeout: Duration,
max_execution_time: Duration,
innode_lock_wait_timeout: Duration,
wait_timeout: Duration,
table_for_election: String,
}Expand description
MySQL client for election.
Fields
current: Option<PoolConnection<MySql>>pool: MySqlPoolexecution_timeout: DurationThe client-side timeout for statement execution.
This timeout is enforced by the client application and is independent of any server-side timeouts. If a statement takes longer than this duration to execute, the client will abort the operation.
max_execution_time: DurationThe maximum execution time for the statement.
This timeout is enforced by the server and is independent of any client-side timeouts. If a statement takes longer than this duration to execute, the server will abort the operation.
innode_lock_wait_timeout: DurationThe lock wait timeout for the session.
This timeout determines how long the server waits for a lock to be acquired before timing out. If a lock cannot be acquired within this duration, the server will abort the operation.
wait_timeout: DurationThe wait timeout for the session.
This timeout determines how long the server waits for activity on a noninteractive connection before closing it. If a connection is idle for longer than this duration, the server will terminate it.
table_for_election: StringThe table name for election.
Implementations
Sourceimpl ElectionMysqlClient
impl ElectionMysqlClient
pub fn new( pool: MySqlPool, execution_timeout: Duration, max_execution_time: Duration, innode_lock_wait_timeout: Duration, wait_timeout: Duration, table_for_election: &str, ) -> Self
fn create_table_sql(&self) -> String
fn insert_once_sql(&self) -> String
fn check_version_sql(&self) -> String
async fn reset_client(&mut self) -> Result<()>
async fn ensure_table_exists(&mut self) -> Result<()>
async fn maybe_init_client(&mut self) -> Result<()>
Sourceasync fn set_session_isolation_level(&mut self) -> Result<()>
async fn set_session_isolation_level(&mut self) -> Result<()>
Sourceasync fn check_version(&mut self, sql: &str) -> Result<()>
async fn check_version(&mut self, sql: &str) -> Result<()>
Sourceasync fn execute(
&mut self,
query: Query<'_, MySql, MySqlArguments>,
sql: &str,
) -> Result<u64>
async fn execute( &mut self, query: Query<'_, MySql, MySqlArguments>, sql: &str, ) -> Result<u64>
Sourceasync fn query(
&mut self,
query: Query<'_, MySql, MySqlArguments>,
sql: &str,
) -> Result<Vec<MySqlRow>>
async fn query( &mut self, query: Query<'_, MySql, MySqlArguments>, sql: &str, ) -> Result<Vec<MySqlRow>>
async fn transaction(&mut self) -> Result<TransactionWithExecutionTimeout<'_>>